@@ -23,21 +23,9 @@
  *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  *    02111-1307 USA
  *
- *******************************************************************************
- *
- * $Id: PCSCperl.h,v 1.3 2002/03/06 08:05:25 rousseau Exp $
- *
- * $Log: PCSCperl.h,v $
- * Revision 1.3  2002/03/06 08:05:25  rousseau
- * comment unused variable declarations
- *
- * Revision 1.2  2001/06/12 13:41:38  giraud
- * Added support for MacOS X
- *
- * Revision 1.1.1.1  2001/05/31 10:00:30  lvictor
- * Initial import
- *
- */
+ ******************************************************************************/
+
+ /* $Id: PCSCperl.h,v 1.5 2003/05/06 21:23:26 rousseau Exp $ */
 
 /******************************************************************************
 *    Contains basic definitions for a Perl wrapper to PCSC-lite. The code
@@ -73,7 +61,7 @@
 #ifdef __linux__
 #  include <dlfcn.h>
 #  include <pcsclite.h>
-#  define LOAD_LIB()      dlopen("libpcsclite.so", RTLD_LAZY)
+#  define LOAD_LIB()      dlopen("libpcsclite.so.0", RTLD_LAZY)
 #  define CLOSE_LIB(x)    dlclose(x)
 #  define DLL_HANDLE      void*
 #  define GET_FCT         dlsym
@@ -117,7 +105,7 @@ DLL_HANDLE LOAD_LIB()
  
     if (!CFBundleLoadExecutable(bundle))
     {
-        CFRelease(bundle);
+	CFRelease(bundle);
 	return NULL;
     }
     return bundle;
